#region Copyright Syncfusion Inc. 2001-2016.
// Copyright Syncfusion Inc. 2001-2016. All rights reserved.
// Use of this code is subject to the terms of our license.
// A copy of the current license can be obtained at any time by e-mailing
// licensing@syncfusion.com. Any infringement will be prosecuted under
// applicable laws. 
#endregion
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.Collections.ObjectModel;
using System.IO;
using Syncfusion.Windows.Forms.Grid.Grouping;
using Syncfusion.Windows.Forms;
using DemoCommon.Grid;

namespace ObservableCollection_Demo
{
    public partial class Form1 : Form
    {
        #region "API Definition"

        EngineEventTracer eventTracer;
        string connectionString = string.Format(@"Data Source = {0}", FindFile("Northwind.sdf"));
        #endregion

        #region "Constructor"

        public Form1()
        {
            
            InitializeComponent();
            this.SampleCustomization();
            //assingning GridGroupingControl Engine.
            GridEngine eng = this.gridGroupingControl1.Engine;

            this.GridSettings();
            //Calling EngineEventTracer constructor .
            //eventTracer = new EngineEventTracer(eng, this.listView1);
                       
        }

        #endregion

        #region "Sample Customization"
        /// <summary>
        /// data binding with an ObservableCollection in GridGroupingControl.
        /// </summary>
        private void SampleCustomization()
        {
            //Setting data source for grid as observable collection.
            this.gridGroupingControl1.DataSource = new Customer(connectionString);
        }

        #region "EventHandlers"
        //used to clear the listView items.
        private void buttonAdv1_Click(object sender, EventArgs e)
        {
            //this.listView1.Items.Clear();
        }
        //used for Hooking and Unhooking events based button text.
        private void button1_Click(object sender, EventArgs e)
        {
            //if (this.button1.Text == "Trace Events")
            //{
            //    this.eventTracer.HookEvents();
            //    //this.button1.Text = "Disable Tracing";
            //}
            //else
            //{
            //    this.eventTracer.UnhookEvents();
            //    this.button1.Text = "Trace Events";
            //}
        }
        //used for enabling Filters for all columns 
        private void Form1_Load(object sender, EventArgs e)
        {
            foreach (GridColumnDescriptor col in this.gridGroupingControl1.TableDescriptor.Columns)
            {
                col.AllowFilter = true;
            }
        }
        
        void gridGroupingControl1_FilterBarSelectedItemChanged(object sender, FilterBarSelectedItemChangedEventArgs e)
        {
            this.eventTracer.AppendOutput("Filtered Column: ", e.Column.Name.ToString());
            this.eventTracer.AppendOutput("SelectedText: ", e.SelectedText);
        }
        #endregion


        #endregion

        #region "Sample Grid Settings"

        /// <summary>
        /// GridGrouping control getting started customization.
        /// </summary>
        private void GridSettings()
        {

            //setting Visual style for grid.
            this.gridGroupingControl1.GridVisualStyles = GridVisualStyles.Metro;
            //enabling Group/drop area.
            this.gridGroupingControl1.ShowGroupDropArea = true;
            //Enabling filters.
            this.gridGroupingControl1.TopLevelGroupOptions.ShowFilterBar = true;
           

            //used to set multiextended selection mode in gridgrouping control. 
            this.gridGroupingControl1.TableOptions.ListBoxSelectionMode = SelectionMode.MultiExtended;

            //used to set GridCaptionRowHeight.
            this.gridGroupingControl1.Table.DefaultCaptionRowHeight = 25;
            this.gridGroupingControl1.Table.DefaultColumnHeaderRowHeight = 30;
            this.gridGroupingControl1.Table.DefaultRecordRowHeight = 22;
            // this.gridGroupingControl1.AllowProportionalColumnSizing = true;
            this.gridGroupingControl1.TableDescriptor.Columns["CustomerID"].HeaderText = "Customer ID";
            this.gridGroupingControl1.TableDescriptor.Columns["CompanyName"].HeaderText = "Company Name";
            this.gridGroupingControl1.TableDescriptor.Columns["ContactName"].HeaderText = "Contact Name";
            this.gridGroupingControl1.TableDescriptor.Columns["ContactTitle"].HeaderText = "Contact Title";
            this.gridGroupingControl1.TableDescriptor.Columns["PostalCode"].HeaderText = "Postal Code";

            //Navigate to other control using tabkey navigation
            this.gridGroupingControl1.WantTabKey = false;

            foreach (GridTableDescriptor td in this.gridGroupingControl1.Engine.EnumerateTableDescriptor())
            {
                if (td.Name == "Orders")
                {
                    td.Columns["OrderID"].HeaderText = "Order ID";
                    td.Columns["CustomerID"].HeaderText = "Customer ID";
                    td.Columns["EmployeeID"].HeaderText = "Employee ID";
                    td.Columns["ShipName"].HeaderText = "Ship Name";

                }
                if (td.Name == "OrderDetails")
                {
                    td.Columns["OrderID"].HeaderText = "Order ID";
                    td.Columns["ProductID"].HeaderText = "Product ID";
                    td.Columns["UnitPrice"].HeaderText = "Unit Price";
                }

            }

            this.gridGroupingControl1.GetTable("Orders").DefaultRecordRowHeight = 22;
            this.gridGroupingControl1.GetTable("OrderDetails").DefaultRecordRowHeight = 22;
            this.gridGroupingControl1.TableDescriptor.Appearance.FilterBarCell.Borders.Bottom = new Syncfusion.Windows.Forms.Grid.GridBorder(Syncfusion.Windows.Forms.Grid.GridBorderStyle.Solid, System.Drawing.Color.LightGray, Syncfusion.Windows.Forms.Grid.GridBorderWeight.Thin);
            this.gridGroupingControl1.TableDescriptor.Appearance.FilterBarCell.Borders.Right = new Syncfusion.Windows.Forms.Grid.GridBorder(Syncfusion.Windows.Forms.Grid.GridBorderStyle.Solid, System.Drawing.Color.LightGray, Syncfusion.Windows.Forms.Grid.GridBorderWeight.Thin);
        }

        #endregion

        private void button1_Click_1(object sender, EventArgs e)
        {
            Northwind northWind = new Northwind(connectionString);
            var customer = northWind.Customers.Skip(0).Take(20).ToList();
                
            this.gridGroupingControl1.DataSource = customer;
        }

        private static string FindFile(string fileName)
        {
            string dataFileName = @"Common\Data\" + fileName;
            for (int n = 0; n < 12; n++)
            {
                if (System.IO.File.Exists(fileName))
                {
                    return new FileInfo(fileName).FullName;
                }
                if (System.IO.File.Exists(dataFileName))
                {
                    return new FileInfo(dataFileName).FullName;
                }
                fileName = @"..\" + fileName;
                dataFileName = @"..\" + dataFileName;
            }

            return fileName;
        }

    }

    #region "DataClass"

    public class Customer : ObservableCollection<Customers>
    {
        Northwind northWind;
        #region "Constructor"
        public Customer(string connectionString)
        {
            
            northWind = new Northwind(connectionString);
            var customer = northWind.Customers.Skip(0).Take(10).ToList();
            foreach (var o in customer)
            {
                this.Add(o);
            }
        }
        #endregion
    }

     #endregion
}
